%{!?kernel_version: %{expand: %%define kernel_version %(uname -r)}}
%{!?kversionreltag: %{expand: %%define kversionreltag %(echo %{kernel_version} |sed -e 's/-/./g')}}
%{!?type: %{expand: %define type %(uname -r | perl -pe 's/^.*el6(.*?).*?$/$1/g'|sed -e 's/^$/smp/g')}}

# On RHEL 6, smp type has no tag
%if "%{type}" != "smp"
%define releasetag %{kversionreltag}.%{type}
%define kernel_dir %{kernel_version}%{type}
%else
%define releasetag %{kversionreltag}
%define kernel_dir %{kernel_version}
%endif

# Definitions for symvers files.
%define vmw_symvers_dir etc/vmware-tools/symvers
%define bld_symvers_file Module.symvers

Name:         vmware-tools-vmsync
BuildRequires: kernel-devel redhat-rpm-config gcc make perl
Vendor:       VMware
License:      GPL
Group:        System/Kernel
Summary:      Contains the source needed to build the vmsync kernel module package (kmp) for the running kernel.
Epoch:        0
Version:      1.1.0.1
Source1:      vmsync-configModule.tar.gz
BuildRoot:    %{_tmppath}/%{name}-%{version}-build

# We define this so our source packages don't contain kernel version in the release
# field but the resulting binary kmod packages they build do.  Only
# necessary on RHEL.
%{?vmw_release:Release:   %{vmw_release}.el6}
%{!?vmw_release:Release:   %{kversionreltag}.3}

Source0:      vmsync.tar
Source2:      vmsync-vmware-PLDP-spec

%define kernel_version %(uname -r|perl -pe 's/^(.*el6.*)$/$1/g'|sed -e 's/^$/default/g')

# Make sure redhat-rpm-config is installed or the
# kernel_module_package macro will throw an error rather than a nice message
%{!?kernel_module_package: You must have the redhat-rpm-config package installed to build this package.}

%define vmware_use_symvers_file 1

# RHEL 6 defines the architecture as i386 by default, even though it's
# an i686 system with i686 kernels.  Define the _arch and _target_cpu
# defaults here so the user doesn't have to specify them on the
# command line
%ifarch i386
%define _arch i686
%define _target_cpu i686
%endif

# Lock down flavors to build to just the current flavor.
%{expand: %%define current_flavor %(uname -r|perl -pe 's/^.*\.el6(.*)\..*?$/$1/g'|perl -pe 's/^$/default/g')}
%kernel_module_package -s %{SOURCE2} %{current_flavor}

%prep
%setup -n vmsync-only

# XXX: We will need to handle the .symvers file for modules
# XXX: with dependent builds.
%build
for flavor in %flavors_to_build; do
  VMCI_SYMVERS_FILE=/%{vmw_symvers_dir}/vmci-9.0.3.0-%{kernel_version}-$flavor

  make clean
  rm -rf ../$flavor ../vmsync.o
  # For modules that depend on vmci, copy in the vmci symvers file
  # or die trying.
  # XXX: I can only handle dependency on one module's symvers file.
  if [ "vmsync" = "vsock" -o "vmsync" = "vmhgfs" ]; then
     if [ ! -e $VMCI_SYMVERS_FILE ]; then
        echo
        echo
        echo "
ERROR: Could not find $VMCI_SYMVERS_FILE.  This package relies on kernel symbols for the currently running kernel that are built from the vmware-tools-vmci source RPM package.  Please do the following:

- Rebuild the vmware-tools-vmci source RPM package.
- Install the resulting binary RPM from \$HOME/rpmbuild/RPMS/\$ARCH/.
- Rebuild this package again."
        echo
        echo
        exit 1
     fi
     cp -f $VMCI_SYMVERS_FILE ./%{bld_symvers_file}
  fi

  # Build it!
  make
  mkdir ../$flavor
  cp ../vmsync.o ../$flavor
  # Take the symvers file with us as well.
  cp ./%{bld_symvers_file} ../$flavor/%{bld_symvers_file}
done

%install
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT
for flavor in %flavors_to_build; do
  vmsync_SYMVERS_FILE=%{vmw_symvers_dir}/vmsync-1.1.0.1-%{kernel_version}-$flavor
  if [ "$flavor" = "default" ]; then
     flavortag=""
  else
     flavortag="$flavor"
  fi
  # Install the module and symvers file.
  install -m 644 -D ../$flavor/vmsync.o $RPM_BUILD_ROOT/lib/modules/%{kernel_version}${flavortag}/extra/%{name}/vmsync.ko
  install -m 644 -D ../$flavor/%{bld_symvers_file} $RPM_BUILD_ROOT/$vmsync_SYMVERS_FILE
done
# Install common files
cd $RPM_BUILD_ROOT && tar xzf %{SOURCE1}

%description
 This package enables you to build binary kernel module packages (kmps) for vmsync.  The vmsync kernel module provides functions used by VMware Tools to freeze I/O to mounted file systems and flush any in-memory data to disk, used when quiescing virtual machines.

%package common
Summary:      Contains the common files used by all the vmsync kernel module packages (kmps).
Group:        System/Kernel
Requires:     perl
Requires:     vmware-tools-foundation >= 0:8.6.10
Release:      1.el6
Version:      8.6.10

%description common
 This package contains the common system configuration and scripts responsible for loading the vmsync kernel module.  The vmsync kernel module provides functions used by VMware Tools to freeze I/O to mounted file systems and flush any in-memory data to disk, used when quiescing virtual machines.

%post common
# Deconfigure if upgrading
if [ $1 -gt 1 ]; then
   if [ -e /etc/init.d/vmsync ]; then
      /sbin/chkconfig vmsync off
   fi
   /usr/lib/vmware-tools/moduleScripts/vmsync/vmware-deconfig.pl --os=linux,rhel,6 --kernel=%{kernel_version} --toDeconfigure=vmsync
   /usr/lib/vmware-tools/moduleScripts/vmsync/vmware-db.pl --os=linux,rhel,6 --dbDelAnswer VMSYNC_NAME
fi

# Configure
/usr/lib/vmware-tools/moduleScripts/vmsync/vmware-db.pl --os=linux,rhel,6 --dbAddAnswer VMSYNC_NAME,vmsync
/usr/lib/vmware-tools/moduleScripts/vmsync/vmware-config.pl --os=linux,rhel,6 --kernel=%{kernel_version} --toConfigure=vmsync
if [ -e /etc/init.d/vmsync ]; then
   /sbin/chkconfig vmsync on
fi

%preun common
# Only deconfigure if we are erasing the package here... not if we are upgrading.
if [ $1 = 0 ]; then
   if [ -e /etc/init.d/vmsync ]; then
      /sbin/chkconfig vmsync off
   fi
   /usr/lib/vmware-tools/moduleScripts/vmsync/vmware-deconfig.pl --os=linux,rhel,6 --kernel=%{kernel_version} --toDeconfigure=vmsync
   /usr/lib/vmware-tools/moduleScripts/vmsync/vmware-db.pl --os=linux,rhel,6 --dbDelAnswer VMSYNC_NAME
fi
%files common
%defattr(-, root, root, -)
/usr/lib/vmware-tools/moduleScripts/vmsync/vmware-pmwv.pl
/usr/lib/vmware-tools/moduleScripts/vmsync/vmware-deconfig.pl
/usr/lib/vmware-tools/moduleScripts/vmsync/vmware-db.pl
/usr/lib/vmware-tools/moduleScripts/vmsync/vmware-config.pl
/etc/rc.d/init.d/vmsync

